@@ -1,7 +1,7 @@
 """Store global configuration information"""
 
 # The current version of duplicity
-version = "0.1.0"
+version = "0.1.1"
 
 # If true, filelists and directory statistics will be split on
 # nulls instead of newlines.
@@ -28,3 +28,11 @@ current_time = None
 # If it is None, default to current time.
 restore_time = None
 
+# If set, use public key encryption to listed keys when backing up,
+# otherwise use symmetric encryption.
+encryption_keys = []
+
+# If set, when encrypting sign with this key, and when decrypting
+# require that the file be signed with this key.
+sign_key = None
+
