@@ -3,6 +3,11 @@
 import os
 import log
 
+class MiscError(Exception):
+	"""Signifies a miscellaneous error..."""
+	pass
+
+
 class FileVolumeWriter:
 	"""Split up an incoming fileobj into multiple volumes on disk
 
@@ -76,7 +81,7 @@ class FileVolumeWriter:
 				return self.prefix
 		else: self.current_index += 1
 		return filename
-			
+
 	def __iter__(self): return self
 
 
@@ -113,3 +118,36 @@ class BufferedFile:
 	def close(self): self.fileobj.close()
 		
 	
+def copyfileobj(infp, outfp, byte_count = -1):
+	"""Copy byte_count bytes from infp to outfp, or all if byte_count < 0
+
+	Returns the number of bytes actually written (may be less than
+	byte_count if find eof.  Does not close either fileobj.
+
+	"""
+	blocksize = 32 * 1024
+	bytes_written = 0
+	if byte_count < 0:
+		while 1:
+			buf = infp.read(blocksize)
+			if not buf: break
+			bytes_written += len(buf)
+			outfp.write(buf)
+	else:
+		while bytes_written + blocksize <= byte_count:
+			buf = infp.read(blocksize)
+			if not buf: break
+			bytes_written += len(buf)
+			outfp.write(buf)
+		buf = infp.read(byte_count - bytes_written)
+		bytes_written += len(buf)
+		outfp.write(buf)
+	return bytes_written
+
+def copyfileobj_close(infp, outfp):
+	"""Copy infp to outfp, closing afterwards"""
+	copyfileobj(infp, outfp)
+	if infp.close(): raise MiscError("Error closing input file")
+	if outfp.close(): raise MiscError("Error closing output file")
+
+
